@@ -10,4 +10,4 @@ echo -e "\033[32m $help \033[0m"
 # 将所有命令中的空格替换成_
 # shell字符串替换用法  单个替换${variable/before/after}  全部替换 ${variable//before/after}
 proc_no_blank=${proc//' '/'_'}
-nohup python "$proc" > "nohup.$proc_no_blank.out" 2>&1 &
\ No newline at end of file
+nohup $proc > "nohup.$proc_no_blank.out" 2>&1 &
